@@ -1,7 +1,7 @@
 #########1#########2#########3#########4#########5#########6#########7#########8
 # vim: ts=8:sw=4
 #
-# $Id: Multiplex.pm,v 2.0.0 2002/11/11 00:01:01 timbo Exp $
+# $Id: Multiplex.pm,v 2.01 2002/11/11 00:01:01 timbo Exp $
 #
 # Copyright (c) 1999,2006 Tim Bunce & Thomas Kishel
 #
@@ -19,7 +19,7 @@ use DBI;
 use strict;
 use vars qw($VERSION $drh $err $errstr $sqlstate);
 
-$VERSION = sprintf("%d.%02d", q$Revision: 2.00 $ =~ /(\d+)\.(\d+)/o);
+$VERSION = sprintf("%d.%02d", q$Revision: 2.02 $ =~ /(\d+)\.(\d+)/o);
 
 $drh = undef;	# Holds driver handle once it has been initialized.
 $err = 0;		# Holds error code for $DBI::err.
@@ -607,11 +607,11 @@ sub AUTOLOAD {
 sub mx_default_statement_mode {
 	my ($statement) = @_;
 	my ($result);
-	
-	if (($$statement =~ /^SELECT/i) && ($$statement !~ /INSERT\s|UPDATE\s|DELETE\s|CREATE\s|DROP\s|INTO\s/i)) {
+
+	$result = '';
+
+	if (! &DBD::Multiplex::mx_is_modify_statement($statement)) {	
 		$result = 'first_success';
-	} else {
-		$result = '';
 	}
 		
 	return $result;
